GooglePlayConfig class

Google Play Store configuration

Constructors

GooglePlayConfig({required String packageName, required String serviceAccountJson})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
packageName → String
Your app's package name (e.g., 'com.example.app')
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccountJson → String
Your Google Service Account credentials JSON string
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited