VerifyPurchaseConfig class

Configuration class for Apple App Store and Google Play Store verification

Constructors

VerifyPurchaseConfig({AppleConfig? appleConfig, GooglePlayConfig? googlePlayConfig, bool enableLogging = false})
const

Properties

appleConfig → AppleConfig?
Apple App Store configuration
final
enableLogging → bool
Prints debug logs (with masked tokens). Off by default.
final
googlePlayConfig → GooglePlayConfig?
Google Play Store configuration
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited