RefundEntry class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
originalId
→ String
-
For Apple: originalTransactionId. For Google: purchaseToken.
final
-
platform
→ StorePlatform
-
final
-
productId
→ String?
-
For Apple: productId from the transaction payload.
For Google: always null — voidedpurchases endpoint does not return productId.
final
-
raw
→ Map<String, dynamic>
-
final
-
reasonCode
→ int?
-
For Apple: always null — SDK 1.2.10 does not expose revocationReason.
For Google: voidedReason (0–7).
final
-
refundDate
→ DateTime
-
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
transactionId
→ String
-
For Apple: transactionId. For Google: orderId.
final
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
override