AppleConfig class
Apple App Store configuration
Constructors
- AppleConfig({required String bundleId, required String issuerId, required String keyId, required String privateKey, AppleEnvironment environment = AppleEnvironment.productionWithSandboxFallback})
-
const
Properties
- bundleId → String
-
Your app's bundle identifier (e.g., 'com.example.app')
final
- environment → AppleEnvironment
-
Environment to query (default: production with sandbox fallback)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- issuerId → String
-
Your App Store Connect API issuer ID
final
- keyId → String
-
Your App Store Connect API key ID
final
- privateKey → String
-
Your App Store Connect API private key (content of the .p8 file)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited